# Delgrada
_Lightweight, minimal tensor-/scalar- based autograd engine._

**Table of Contents**
- [Get Started](#get-started)
- [About](#about)
- [Cool Features](#cool-features)
- [License](#license)

## Get Started

Run `pip install delgrada`.

## About

The code in this repository is the product of a long-haul flight. Bored and without Internet access, naturally, I decided to build an autograd library.

`delgrada` is built mainly for fun and education. It is inspired by Andrej Karpathy's [micrograd](https://github.com/karpathy/micrograd) library, but seeks to generalise for tensor-valued operations and offer full compatibility with numpy.

## Cool Features

## License

The code in this repository is under the MIT License.

Copyright (c) 2024 Yiding Song
